@@ -1,5 +1,5 @@
 from typing import Tuple, List
-from abc import ABC, abstractmethod
+from abc import ABC, abstractmethod, abstractclassmethod
 
 
 class Indexer(ABC):
@@ -27,7 +27,7 @@ class Indexer(ABC):
         """
         pass
 
-    @abstractmethod
+    @abstractclassmethod
     def load(self, path) -> "Indexer":
         """
         Load the indexer in a path.
@@ -37,7 +37,7 @@ class Indexer(ABC):
         """
         pass
 
-    def query(self, query, n_neighbors=1) -> Tuple[List, List]:
+    def query(self, item, n_neighbors=1) -> Tuple[List, List]:
         """
         Query the index.
 
@@ -45,7 +45,4 @@ class Indexer(ABC):
             query: The query to query the index with.
             n_neighbors: The number of neighbors to return.
         """
-        if not self.model:
-            raise RuntimeError("Index not yet built.")
-        idx, dist = self.model.query(query, n_neighbors)
-        return list(idx[0]), list(dist[0])
+        pass
